using System;
using System.Data;

using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.UI;
using System.Collections.Generic;

public partial class Admin_Controls_PageHierarchy : WebBlockUserControl
{
    #region Private Members
    private bool AlternatingRow = true;
    private DataTable BreadcrumbTable = null;
    private string expandUrl;
    private string collapseUrl;
    #endregion

    #region Public Properties
    private int _CategoryID = 0;
    public int CategoryID
    {
        get { return _CategoryID; }
        set { _CategoryID = value; }
    }
    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        // get our web resources
        expandUrl = Page.ClientScript.GetWebResourceUrl(typeof(System.Web.UI.WebControls.TreeView), "TreeView_Default_Expand.gif");
        collapseUrl = Page.ClientScript.GetWebResourceUrl(typeof(System.Web.UI.WebControls.TreeView), "TreeView_Default_Collapse.gif");
        string jsText = String.Format("var expandUrl='{0}'; var collapseUrl='{1}';", expandUrl, collapseUrl);
        Page.ClientScript.RegisterClientScriptBlock(typeof(string), "urls", jsText, true);
    }

    protected override void Render(HtmlTextWriter writer)
    {
        DataTable dtCats = Database.Categories_GetRootCategories();
        DataTable dtProds = Database.Selectors_GetByCategoryID(0);

        // if we need to open up to a specific category, we'll need the breadcrumb trail to get there
        if (CategoryID > 0)
            BreadcrumbTable = Database.Categories_GetBreadcrumbTrail(_CategoryID, 0, false);

        // now call a function to render out this datatable correctly
        // at the render depth of 0
        RenderDataTable(writer, dtCats, dtProds, 0);
    }

    private void RenderDataTable(HtmlTextWriter writer, DataTable Categories, DataTable Products, int RenderDepth)
    {
        // we want to iterate through the first layer of subcategories
        // until we hit the category we need to expand on
        // this is returned as the last row of GetBreadcrumbTrail
        int TargetCategoryID = 0;

        if (BreadcrumbTable != null && BreadcrumbTable.Rows.Count - RenderDepth > 0)
            TargetCategoryID = (int)BreadcrumbTable.Rows[BreadcrumbTable.Rows.Count - RenderDepth - 1]["CategoryID"];

        // enclosing table
        writer.Write("<table class=\"categorydatabase\">");

        if (Categories.Rows.Count == 0)
        {
            writer.Write("<tr><td class='sortDiv'><b>0 Categories:</b> <a href=\"EditCategory.aspx?CategoryID=" + CategoryID.ToString() + "\">Add New Category</a></td></tr>");
        }
        else
        {
            // render the sort/add links
            if (RenderDepth == 0)
            {
                // for the root..
                writer.Write("<tr><td class='sortDiv'><b>");
                writer.Write(Categories.Rows.Count.ToString());
                writer.Write(" Categories:</b> <a href=\"javascript:LoadSubWindow('SortCategory.aspx?CategoryID=0&redirect=true');\">Sort</a> | <a href=\"EditCategory.aspx\">Add New Category</a></td></tr>");
            }
            else
            {
                // for everyone else
                writer.Write("<tr><td class='sortDiv'><b>");
                writer.Write(Categories.Rows.Count.ToString());
                writer.Write(" Sub-Categories:</b> <a href=\"javascript:LoadSubWindow('SortCategory.aspx?CategoryID=");
                writer.Write(CategoryID.ToString());
                writer.Write("&redirect=true');\">Sort</a> | <a href=\"EditCategory.aspx?ParentCategoryID=");
                writer.Write(CategoryID.ToString());
                writer.Write("\">Add New Category</a></td></tr>");
            }

            foreach (DataRow dr in Categories.Rows)
            {
                AlternatingRow = !AlternatingRow;
                writer.Write("<tr");
                if (AlternatingRow)
                {
                    writer.Write(" class=\"alternatingrow\"");
                }

                writer.Write(">");
                if ((int)dr["CategoryID"] == TargetCategoryID)
                {
                    writer.Write("<td class=\"categoryname\" expanded=\"true\">");
                    writer.Write("<a href=\"javascript:void(0);\" onClick=\"toggleCategory(this.parentNode,");
                    writer.Write(dr["CategoryID"].ToString());
                    writer.Write("); return false;\"><img src=\"");
                    writer.Write(collapseUrl);
                    writer.Write("\" border=\"0\" align=\"absmiddle\" /></a>");
                }
                else
                {
                    writer.Write("<td class=\"categoryname\" expanded=\"false\">");
                    writer.Write("<a href=\"javascript:void(0);\" onClick=\"toggleCategory(this.parentNode,");
                    writer.Write(dr["CategoryID"].ToString());
                    writer.Write("); return false;\"><img src=\"");
                    writer.Write(expandUrl);
                    writer.Write("\" border=\"0\" align=\"absmiddle\" /></a>");
                }

                writer.Write("<a href=\"");
                writer.Write("EditCategory.aspx?CategoryID=");
                writer.Write(dr["CategoryID"].ToString());
                writer.Write("\">");
                writer.Write((string)dr["CategoryName"]);
                writer.Write("</a>");

                if ((int)dr["CategoryID"] == TargetCategoryID)
                    RenderSubCategories(writer, RenderDepth + 1);

                writer.Write("</td></tr>");
            }
        }

        if (RenderDepth > 0)
        {
            if (Products.Rows.Count == 0)
            {
                writer.Write("<tr><td class='sortDiv'><b>0 Product Pages:</b> <a href=\"EditSelector_Basics.aspx?CategoryID=" + CategoryID.ToString() + "\">Add New Product Page</a></td></tr>");
            }
            else
            {
                // render the sort/add links
                writer.Write("<tr><td class='sortDiv'><b>");
                writer.Write(Products.Rows.Count.ToString());
                writer.Write(" Product Pages:</b> <a href=\"javascript:LoadSubWindow('SortProducts.aspx?CategoryID=");
                writer.Write(CategoryID.ToString());
                writer.Write("&redirect=true');\">Sort</a> | <a href=\"EditSelector_Basics.aspx?CategoryID=");
                writer.Write(CategoryID.ToString());
                writer.Write("\">Add New Category</a></td></tr>");

                foreach (DataRow dr in Products.Rows)
                {
                    AlternatingRow = !AlternatingRow;
                    writer.Write("<tr");
                    if (AlternatingRow)
                        writer.Write(" class=\"alternatingrow\"");
                    writer.Write(">");
                    writer.Write("<td class=\"productname\">");

                    writer.Write("<a href=\"EditSelector_Basics.aspx?SelectorID=");
                    writer.Write(dr["SelectorID"].ToString());
                    writer.Write("\">");

                    if (dr["SKU"] != DBNull.Value && ((string)dr["SKU"]).Length > 0)
                    {
                        writer.Write("<span style='color: red; font-weight: bold;'>(");
                        writer.Write((string)dr["SKU"]);
                        writer.Write("</span>) ");
                    }

                    writer.Write((string)dr["Name"]);
                    writer.Write("</a>");

                    writer.Write("</td></tr>");
                }
            }
        }

        // close the table
        writer.Write("</table>");
    }

    private void RenderSubCategories(HtmlTextWriter writer, int RenderDepth)
    {
        int ThisCategoryID = (int)BreadcrumbTable.Rows[BreadcrumbTable.Rows.Count - RenderDepth]["CategoryID"];

        writer.Write("<div class=\"contentDiv\">");

        DataTable dtCats = Database.Categories_GetChildren(ThisCategoryID);
        DataTable dtProds = Database.Selectors_GetByCategoryID(ThisCategoryID);

        CategoryID = ThisCategoryID;
        RenderDataTable(writer, dtCats, dtProds, RenderDepth);

        writer.Write("</div>");
    }
}
