using System;
using System.Data;

using System.Configuration;
using System.Text.RegularExpressions;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Text;

public class Utilities
{
    public static Regex nonAlphaNumerics = new Regex("[^a-zA-Z0-9]+", RegexOptions.Compiled);
    public static Regex nonAlphaNumericsAtEdges = new Regex("(^[^a-zA-Z0-9]+)|([^a-zA-Z0-9]+$)", RegexOptions.Compiled);
    public static Regex ValidateBrowseString = new Regex("^/\\d+/[^/]+(/\\d+)*$", RegexOptions.Compiled);


    #region CSV Producer
    public static void ExportCSVToBrowser(DataTable dt, HttpResponse Response, string filename)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.ContentType = "text/csv";
        Response.AddHeader("Content-Disposition", "inline;filename=" + filename);
        Response.Charset = "";
        ProduceCSV(dt, Response.Output, true);
        Response.End();
    }
    public static void ExportCSVToStream(DataTable dt, System.IO.TextWriter httpStream, bool WriteHeader)
    {
        ProduceCSV(dt, httpStream, WriteHeader);
    }
    internal static void ProduceCSV(DataTable dt, System.IO.TextWriter httpStream, bool WriteHeader)
    {
        if (WriteHeader)
        {
            string[] arr = new String[dt.Columns.Count];
            for (int i = 0; i < dt.Columns.Count; i++)
            {
                arr[i] = dt.Columns[i].ColumnName;
                arr[i] = CSV_GetWriteableValue(arr[i]);
            }

            httpStream.WriteLine(string.Join(",", arr));
        }

        for (int j = 0; j < dt.Rows.Count; j++)
        {
            string[] dataArr = new String[dt.Columns.Count];
            for (int i = 0; i < dt.Columns.Count; i++)
            {
                object o = dt.Rows[j][i];
                dataArr[i] = CSV_GetWriteableValue(o);
            }
            httpStream.WriteLine(string.Join(",", dataArr));
        }
    }
    internal static string CSV_GetWriteableValue(object o)
    {
        if (o == null || o == Convert.DBNull)
            return "";
        else if (o.ToString().IndexOf(",") == -1)
            return o.ToString();
        else
            return "\"" + o.ToString() + "\"";
    }
    #endregion

    public static string FormatCategoryUrl(int CategoryId, string Name)
    {
        StringBuilder sb = new StringBuilder(4);
        sb.Append("Browse.aspx/");
        sb.Append(CategoryId);
        sb.Append("/");
        sb.Append(Name.Replace(' ', '-').Replace('/', '-').Replace('.', '-').Replace('?', '-').Replace(':', '-'));
        return sb.ToString();
    }

    public static string FormatProductUrl(int CategorySelectorMapId, string Name)
    {
        StringBuilder sb = new StringBuilder(4);
        sb.Append("View.aspx/");
        sb.Append(CategorySelectorMapId);
        sb.Append("/");
        sb.Append(Name.Replace(' ', '-').Replace('/', '-').Replace('.', '-').Replace('?', '-').Replace(':', '-'));
        return sb.ToString();
    }

    public static void DeleteProductPhoto(string Filename)
    {
        if (Filename.Length > 0 && Filename.LastIndexOf('.') > 0)
        {
            // loop through photos and delete
            string PhotoDirectory = HttpContext.Current.Server.MapPath("~/ProductPhotos/");
            string FilenameWithPath = PhotoDirectory + Filename;
            string FilenameWithoutExtension = Filename.Substring(0, Filename.LastIndexOf('.'));
            string FilenameExtension = Filename.Substring(Filename.LastIndexOf('.') + 1);

            try
            {
                if (System.IO.File.Exists(FilenameWithPath))
                    System.IO.File.Delete(FilenameWithPath);

                string[] CachedImages = System.IO.Directory.GetFiles(HttpContext.Current.Server.MapPath("~/ImageCache/"));

                foreach (string sFile in CachedImages)
                {
                    string RawFilename = sFile.Substring(sFile.LastIndexOf('\\') + 1);
                    if (RawFilename.StartsWith(FilenameWithoutExtension) && RawFilename.EndsWith(FilenameExtension))
                        System.IO.File.Delete(sFile);
                }
            }
            catch { } // no failing allowed
        }
    }

    public static string GenerateRandomString(int Length)
    {
        Random r = new Random();
        byte[] bPass = new byte[Length*2];
        r.NextBytes(bPass);
        return Convert.ToBase64String(bPass).Substring(0, Length);
    }

    #region front-end population functions
    public static void PopulateCountryList(DropDownList target)
    {
        target.Items.Add(new ListItem("Select", ""));
        target.Items.Add(new ListItem("UNITED STATES", "USA"));
        target.Items.Add(new ListItem("CANADA", "CAN"));
        /*
        target.Items.Add(new ListItem("AFGHANISTAN", "AFG"));
        target.Items.Add(new ListItem("ALBANIA", "ALB"));
        target.Items.Add(new ListItem("ALGERIA", "ALG"));
        target.Items.Add(new ListItem("AMERICAN SAMOA", "ASM"));
        target.Items.Add(new ListItem("ANDORRA", "AND"));
        target.Items.Add(new ListItem("ANGOLA", "AGL"));
        target.Items.Add(new ListItem("ANGUILLA", "AIA"));
        target.Items.Add(new ListItem("ANTARCTICA", "ATA"));
        target.Items.Add(new ListItem("ANTIGUA AND BARBUDA", "ATG"));
        target.Items.Add(new ListItem("ARGENTINA", "ARG"));
        target.Items.Add(new ListItem("ARMENIA", "ARM"));
        target.Items.Add(new ListItem("ARUBA", "ABW"));
        target.Items.Add(new ListItem("AUSTRALIA", "AUS"));
        target.Items.Add(new ListItem("AUSTRIA", "AUT"));
        target.Items.Add(new ListItem("AZERBAIJAN", "AZE"));
        target.Items.Add(new ListItem("BAHAMAS", "BAH"));
        target.Items.Add(new ListItem("BAHRAIN", "BHR"));
        target.Items.Add(new ListItem("BANGLADESH", "BGD"));
        target.Items.Add(new ListItem("BARBADOS", "BRB"));
        target.Items.Add(new ListItem("BELARUS", "BLR"));
        target.Items.Add(new ListItem("BELGIUM", "BEL"));
        target.Items.Add(new ListItem("BELIZE", "BLZ"));
        target.Items.Add(new ListItem("BENIN", "BEN"));
        target.Items.Add(new ListItem("BERMUDA", "BMU"));
        target.Items.Add(new ListItem("BHUTAN", "BTN"));
        target.Items.Add(new ListItem("BOLIVIA", "BOL"));
        target.Items.Add(new ListItem("BOSNIA AND HERZEGOVINA", "BIH"));
        target.Items.Add(new ListItem("BOTSWANA", "BOT"));
        target.Items.Add(new ListItem("BOUVET ISLAND", "BVT"));
        target.Items.Add(new ListItem("BRAZIL", "BRA"));
        target.Items.Add(new ListItem("BRITISH INDIAN OCEAN TERRITORY", "IOT"));
        target.Items.Add(new ListItem("BRUNEI DARUSSALAM", "BRU"));
        target.Items.Add(new ListItem("BULGARIA", "BUL"));
        target.Items.Add(new ListItem("BURKINA FASO", "BFA"));
        target.Items.Add(new ListItem("BURUNDI", "BDI"));
        target.Items.Add(new ListItem("CAMBODIA", "CBG"));
        target.Items.Add(new ListItem("CAMEROON", "CME"));
        target.Items.Add(new ListItem("CAPE VERDE", "CPV"));
        target.Items.Add(new ListItem("CAYMAN ISLANDS", "CYM"));
        target.Items.Add(new ListItem("CENTRAL AFRICAN REPUBLIC", "CAF"));
        target.Items.Add(new ListItem("CHAD", "TCD"));
        target.Items.Add(new ListItem("CHILE", "CHL"));
        target.Items.Add(new ListItem("CHINA", "CHN"));
        target.Items.Add(new ListItem("CHRISTMAS ISLAND", "CXR"));
        target.Items.Add(new ListItem("COCOS (KEELING) ISLANDS", "CCK"));
        target.Items.Add(new ListItem("COLOMBIA", "CLM"));
        target.Items.Add(new ListItem("COMOROS", "COM"));
        target.Items.Add(new ListItem("CONGO", "COG"));
        target.Items.Add(new ListItem("CONGO, THE DEMOCRATIC REPUBLIC OF THE", "COD"));
        target.Items.Add(new ListItem("COOK ISLANDS", "COK"));
        target.Items.Add(new ListItem("COSTA RICA", "CTR"));
        target.Items.Add(new ListItem("CTE D'IVOIRE", "CTI"));
        target.Items.Add(new ListItem("CROATIA", "HRV"));
        target.Items.Add(new ListItem("CUBA", "CUB"));
        target.Items.Add(new ListItem("CYPRUS", "CYP"));
        target.Items.Add(new ListItem("CZECH REPUBLIC", "CZE"));
        target.Items.Add(new ListItem("DENMARK", "DNK"));
        target.Items.Add(new ListItem("DJIBOUTI", "DJI"));
        target.Items.Add(new ListItem("DOMINICA", "DMA"));
        target.Items.Add(new ListItem("DOMINICAN REPUBLIC", "DOM"));
        target.Items.Add(new ListItem("ECUADOR", "EQA"));
        target.Items.Add(new ListItem("EGYPT", "EGY"));
        target.Items.Add(new ListItem("EL SALVADOR", "SLV"));
        target.Items.Add(new ListItem("EQUATORIAL GUINEA", "GNE"));
        target.Items.Add(new ListItem("ERITREA", "ERI"));
        target.Items.Add(new ListItem("ESTONIA", "EST"));
        target.Items.Add(new ListItem("ETHIOPIA", "ETH"));
        target.Items.Add(new ListItem("FALKLAND ISLANDS (MALVINAS)", "FLK"));
        target.Items.Add(new ListItem("FAROE ISLANDS", "FRO"));
        target.Items.Add(new ListItem("FIJI", "FJI"));
        target.Items.Add(new ListItem("FINLAND", "FIN"));
        target.Items.Add(new ListItem("FRANCE", "FRA"));
        target.Items.Add(new ListItem("FRENCH GUIANA", "GUF"));
        target.Items.Add(new ListItem("FRENCH POLYNESIA", "PYF"));
        target.Items.Add(new ListItem("FRENCH SOUTHERN TERRITORIES", "ATF"));
        target.Items.Add(new ListItem("GABON", "GAB"));
        target.Items.Add(new ListItem("GAMBIA", "GMB"));
        target.Items.Add(new ListItem("GEORGIA", "GEO"));
        target.Items.Add(new ListItem("GERMANY", "DEU"));
        target.Items.Add(new ListItem("GHANA", "GHA"));
        target.Items.Add(new ListItem("GIBRALTAR", "GIB"));
        target.Items.Add(new ListItem("GREECE", "GRC"));
        target.Items.Add(new ListItem("GREENLAND", "GRL"));
        target.Items.Add(new ListItem("GRENADA", "GRD"));
        target.Items.Add(new ListItem("GUADELOUPE", "GLP"));
        target.Items.Add(new ListItem("GUAM", "GUM"));
        target.Items.Add(new ListItem("GUATEMALA", "GTM"));
        target.Items.Add(new ListItem("GUINEA", "GUI"));
        target.Items.Add(new ListItem("GUINEA-BISSAU", "GNB"));
        target.Items.Add(new ListItem("GUYANA", "GUY"));
        target.Items.Add(new ListItem("HAITI", "HTI"));
        target.Items.Add(new ListItem("HEARD ISLAND AND MCDONALD ISLANDS", "HMD"));
        target.Items.Add(new ListItem("HOLY SEE (VATICAN CITY STATE)", "VAT"));
        target.Items.Add(new ListItem("HONDURAS", "HND"));
        target.Items.Add(new ListItem("HONG KONG", "HKG"));
        target.Items.Add(new ListItem("HUNGARY", "HNG"));
        target.Items.Add(new ListItem("ICELAND", "ISL"));
        target.Items.Add(new ListItem("INDIA", "IND"));
        target.Items.Add(new ListItem("INDONESIA", "INS"));
        target.Items.Add(new ListItem("IRAN, ISLAMIC REPUBLIC OF", "IRN"));
        target.Items.Add(new ListItem("IRAQ", "IRQ"));
        target.Items.Add(new ListItem("IRELAND", "IRL"));
        target.Items.Add(new ListItem("ISRAEL", "ISR"));
        target.Items.Add(new ListItem("ITALY", "ITA"));
        target.Items.Add(new ListItem("JAMAICA", "JMC"));
        target.Items.Add(new ListItem("JAPAN", "JPN"));
        target.Items.Add(new ListItem("JORDAN", "JOR"));
        target.Items.Add(new ListItem("KAZAKHSTAN", "KAZ"));
        target.Items.Add(new ListItem("KENYA", "KEN"));
        target.Items.Add(new ListItem("KIRIBATI", "KIR"));
        target.Items.Add(new ListItem("KOREA, DEMOCRATIC PEOPLE'S REPUBLIC OF", "KRE"));
        target.Items.Add(new ListItem("KOREA, REPUBLIC OF", "KOR"));
        target.Items.Add(new ListItem("KUWAIT", "KWT"));
        target.Items.Add(new ListItem("KYRGYZSTAN", "KGZ"));
        target.Items.Add(new ListItem("LAO PEOPLE'S DEMOCRATIC REPUBLIC", "LAO"));
        target.Items.Add(new ListItem("LATVIA", "LVA"));
        target.Items.Add(new ListItem("LEBANON", "LBN"));
        target.Items.Add(new ListItem("LESOTHO", "LSO"));
        target.Items.Add(new ListItem("LIBERIA", "LBR"));
        target.Items.Add(new ListItem("LIBYAN ARAB JAMAHIRIYA", "LBY"));
        target.Items.Add(new ListItem("LIECHTENSTEIN", "LIE"));
        target.Items.Add(new ListItem("LITHUANIA", "LTU"));
        target.Items.Add(new ListItem("LUXEMBOURG", "LUX"));
        target.Items.Add(new ListItem("MACAO", "MAC"));
        target.Items.Add(new ListItem("MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF", "MKD"));
        target.Items.Add(new ListItem("MADAGASCAR", "MDG"));
        target.Items.Add(new ListItem("MALAWI", "MWI"));
        target.Items.Add(new ListItem("MALAYSIA", "MLA"));
        target.Items.Add(new ListItem("MALDIVES", "MLD"));
        target.Items.Add(new ListItem("MALI", "MLI"));
        target.Items.Add(new ListItem("MALTA", "MLT"));
        target.Items.Add(new ListItem("MARSHALL ISLANDS", "MHL"));
        target.Items.Add(new ListItem("MARTINIQUE", "MTQ"));
        target.Items.Add(new ListItem("MAURITANIA", "MTN"));
        target.Items.Add(new ListItem("MAURITIUS", "MAU"));
        target.Items.Add(new ListItem("MAYOTTE", "MYT"));
        target.Items.Add(new ListItem("MEXICO", "MEX"));
        target.Items.Add(new ListItem("MOLDOVA, REPUBLIC OF", "MDA"));
        target.Items.Add(new ListItem("MONACO", "MCO"));
        target.Items.Add(new ListItem("MONGOLIA", "MNG"));
        target.Items.Add(new ListItem("MONTSERRAT", "MSR"));
        target.Items.Add(new ListItem("MOROCCO", "MRC"));
        target.Items.Add(new ListItem("MOZAMBIQUE", "MOZ"));
        target.Items.Add(new ListItem("MYANMAR", "BRM"));
        target.Items.Add(new ListItem("NAMIBIA", "NMB"));
        target.Items.Add(new ListItem("NAURU", "NRU"));
        target.Items.Add(new ListItem("NEPAL", "NPL"));
        target.Items.Add(new ListItem("NETHERLANDS", "NLD"));
        target.Items.Add(new ListItem("NETHERLANDS ANTILLES", "ANT"));
        target.Items.Add(new ListItem("NEW CALEDONIA", "NCL"));
        target.Items.Add(new ListItem("NEW ZEALAND", "NZL"));
        target.Items.Add(new ListItem("NICARAGUA", "NIC"));
        target.Items.Add(new ListItem("NIGER", "NGR"));
        target.Items.Add(new ListItem("NIGERIA", "NIG"));
        target.Items.Add(new ListItem("NIUE", "NIU"));
        target.Items.Add(new ListItem("NORFOLK ISLAND", "NFK"));
        target.Items.Add(new ListItem("NORTHERN MARIANA ISLANDS", "MNP"));
        target.Items.Add(new ListItem("NORWAY", "NOR"));
        target.Items.Add(new ListItem("OMAN", "OMN"));
        target.Items.Add(new ListItem("PAKISTAN", "PAK"));
        target.Items.Add(new ListItem("PALAU", "PLW"));
        target.Items.Add(new ListItem("PANAMA", "PNR"));
        target.Items.Add(new ListItem("PAPUA NEW GUINEA", "PNG"));
        target.Items.Add(new ListItem("PARAGUAY", "PRG"));
        target.Items.Add(new ListItem("PERU", "PRU"));
        target.Items.Add(new ListItem("PHILIPPINES", "PHL"));
        target.Items.Add(new ListItem("PITCAIRN", "PCN"));
        target.Items.Add(new ListItem("POLAND", "POL"));
        target.Items.Add(new ListItem("PORTUGAL", "POR"));
        target.Items.Add(new ListItem("PUERTO RICO", "PRI"));
        target.Items.Add(new ListItem("QATAR", "QAT"));
        target.Items.Add(new ListItem("RUNION", "REU"));
        target.Items.Add(new ListItem("ROMANIA", "ROM"));
        target.Items.Add(new ListItem("RUSSIAN FEDERATION", "RUS"));
        target.Items.Add(new ListItem("RWANDA", "RWA"));
        target.Items.Add(new ListItem("SAINT HELENA", "SHN"));
        target.Items.Add(new ListItem("SAINT KITTS AND NEVIS", "KNA"));
        target.Items.Add(new ListItem("SAINT LUCIA", "LCA"));
        target.Items.Add(new ListItem("SAINT PIERRE AND MIQUELON", "SPM"));
        target.Items.Add(new ListItem("SAINT VINCENT AND THE GRENADINES", "VCT"));
        target.Items.Add(new ListItem("SAMOA", "WSM"));
        target.Items.Add(new ListItem("SAN MARINO", "SMR"));
        target.Items.Add(new ListItem("SAO TOME AND PRINCIPE", "STP"));
        target.Items.Add(new ListItem("SAUDI ARABIA", "SAU"));
        target.Items.Add(new ListItem("SENEGAL", "SEN"));
        target.Items.Add(new ListItem("SERBIA AND MONTENEGRO", "SCG"));
        target.Items.Add(new ListItem("SEYCHELLES", "SEY"));
        target.Items.Add(new ListItem("SIERRA LEONE", "SRL"));
        target.Items.Add(new ListItem("SINGAPORE", "SGP"));
        target.Items.Add(new ListItem("SLOVAKIA", "SVK"));
        target.Items.Add(new ListItem("SLOVENIA", "SVN"));
        target.Items.Add(new ListItem("SOLOMON ISLANDS", "SLB"));
        target.Items.Add(new ListItem("SOMALIA", "SOM"));
        target.Items.Add(new ListItem("SOUTH AFRICA", "ZAF"));
        target.Items.Add(new ListItem("SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS", "SGS"));
        target.Items.Add(new ListItem("SPAIN", "ESP"));
        target.Items.Add(new ListItem("SRI LANKA", "LKA"));
        target.Items.Add(new ListItem("SUDAN", "SDN"));
        target.Items.Add(new ListItem("SURINAME", "SUR"));
        target.Items.Add(new ListItem("SVALBARD AND JAN MAYEN", "SJM"));
        target.Items.Add(new ListItem("SWAZILAND", "SWZ"));
        target.Items.Add(new ListItem("SWEDEN", "SWE"));
        target.Items.Add(new ListItem("SWITZERLAND", "CHE"));
        target.Items.Add(new ListItem("SYRIAN ARAB REPUBLIC", "SYR"));
        target.Items.Add(new ListItem("TAIWAN, PROVINCE OF CHINA", "TWN"));
        target.Items.Add(new ListItem("TAJIKISTAN", "TJK"));
        target.Items.Add(new ListItem("TANZANIA, UNITED REPUBLIC OF", "TZA"));
        target.Items.Add(new ListItem("THAILAND", "THA"));
        target.Items.Add(new ListItem("TOGO", "TGO"));
        target.Items.Add(new ListItem("TOKELAU", "TKL"));
        target.Items.Add(new ListItem("TONGA", "TON"));
        target.Items.Add(new ListItem("TRINIDAD AND TOBAGO", "TTO"));
        target.Items.Add(new ListItem("TUNISIA", "TUN"));
        target.Items.Add(new ListItem("TURKEY", "TUR"));
        target.Items.Add(new ListItem("TURKMENISTAN", "TKM"));
        target.Items.Add(new ListItem("TURKS AND CAICOS ISLANDS", "TCA"));
        target.Items.Add(new ListItem("TUVALU", "TUV"));
        target.Items.Add(new ListItem("UGANDA", "UGA"));
        target.Items.Add(new ListItem("UKRAINE", "UKR"));
        target.Items.Add(new ListItem("UNITED ARAB EMIRATES", "ARE"));
        target.Items.Add(new ListItem("UNITED KINGDOM", "GBR"));
        target.Items.Add(new ListItem("UNITED STATES MINOR OUTLYING ISLANDS", "UMI"));
        target.Items.Add(new ListItem("URUGUAY", "URY"));
        target.Items.Add(new ListItem("UZBEKISTAN", "UZB"));
        target.Items.Add(new ListItem("VANUATU", "VUT"));
        target.Items.Add(new ListItem("VENEZUELA", "VEN"));
        target.Items.Add(new ListItem("VIET NAM", "VNN"));
        target.Items.Add(new ListItem("VIRGIN ISLANDS, BRITISH", "VGB"));
        target.Items.Add(new ListItem("VIRGIN ISLANDS, U.S.", "VIR"));
        target.Items.Add(new ListItem("WALLIS AND FUTUNA", "WLF"));
        target.Items.Add(new ListItem("WESTERN SAHARA", "ESH"));
        target.Items.Add(new ListItem("YEMEN", "YEM"));
        target.Items.Add(new ListItem("ZAMBIA", "ZMB"));
        target.Items.Add(new ListItem("ZIMBABWE", "ZWE"));
        */
    }

    public static void PopulateStateList(DropDownList target)
    {
        target.Items.Add(new ListItem("Select", ""));
        target.Items.Add(new ListItem("Alabama", "AL"));
        target.Items.Add(new ListItem("Alaska", "AK"));
        target.Items.Add(new ListItem("Arizona", "AZ"));
        target.Items.Add(new ListItem("Arkansas", "AR"));
        target.Items.Add(new ListItem("California", "CA"));
        target.Items.Add(new ListItem("Colorado", "CO"));
        target.Items.Add(new ListItem("Connecticut", "CT"));
        target.Items.Add(new ListItem("Delaware", "DE"));
        target.Items.Add(new ListItem("District Of Columbia", "DC"));
        target.Items.Add(new ListItem("Florida", "FL"));
        target.Items.Add(new ListItem("Georgia", "GA"));
        target.Items.Add(new ListItem("Hawaii", "HI"));
        target.Items.Add(new ListItem("Idaho", "ID"));
        target.Items.Add(new ListItem("Illinois", "IL"));
        target.Items.Add(new ListItem("Indiana", "IN"));
        target.Items.Add(new ListItem("Iowa", "IA"));
        target.Items.Add(new ListItem("Kansas", "KS"));
        target.Items.Add(new ListItem("Kentucky", "KY"));
        target.Items.Add(new ListItem("Louisiana", "LA"));
        target.Items.Add(new ListItem("Maine", "ME"));
        target.Items.Add(new ListItem("Maryland", "MD"));
        target.Items.Add(new ListItem("Massachusetts", "MA"));
        target.Items.Add(new ListItem("Michigan", "MI"));
        target.Items.Add(new ListItem("Minnesota", "MN"));
        target.Items.Add(new ListItem("Mississippi", "MS"));
        target.Items.Add(new ListItem("Missouri", "MO"));
        target.Items.Add(new ListItem("Montana", "MT"));
        target.Items.Add(new ListItem("Nebraska", "NE"));
        target.Items.Add(new ListItem("Nevada", "NV"));
        target.Items.Add(new ListItem("New Hampshire", "NH"));
        target.Items.Add(new ListItem("New Jersey", "NJ"));
        target.Items.Add(new ListItem("New Mexico", "NM"));
        target.Items.Add(new ListItem("New York", "NY"));
        target.Items.Add(new ListItem("North Carolina", "NC"));
        target.Items.Add(new ListItem("North Dakota", "ND"));
        target.Items.Add(new ListItem("Ohio", "OH"));
        target.Items.Add(new ListItem("Oklahoma", "OK"));
        target.Items.Add(new ListItem("Oregon", "OR"));
        target.Items.Add(new ListItem("Pennsylvania", "PA"));
        target.Items.Add(new ListItem("Rhode Island", "RI"));
        target.Items.Add(new ListItem("South Carolina", "SC"));
        target.Items.Add(new ListItem("South Dakota", "SD"));
        target.Items.Add(new ListItem("Tennessee", "TN"));
        target.Items.Add(new ListItem("Texas", "TX"));
        target.Items.Add(new ListItem("Utah", "UT"));
        target.Items.Add(new ListItem("Vermont", "VT"));
        target.Items.Add(new ListItem("Virginia", "VA"));
        target.Items.Add(new ListItem("Washington", "WA"));
        target.Items.Add(new ListItem("West Virginia", "WV"));
        target.Items.Add(new ListItem("Wisconsin", "WI"));
        target.Items.Add(new ListItem("Wyoming", "WY"));
    }

    public static void PopulateExpirationMonths(DropDownList target)
    {
        target.Items.Add(new ListItem("01 - January", "01"));
        target.Items.Add(new ListItem("02 - February", "02"));
        target.Items.Add(new ListItem("03 - March", "03"));
        target.Items.Add(new ListItem("04 - April", "04"));
        target.Items.Add(new ListItem("05 - May", "05"));
        target.Items.Add(new ListItem("06 - June", "06"));
        target.Items.Add(new ListItem("07 - July", "07"));
        target.Items.Add(new ListItem("08 - August", "08"));
        target.Items.Add(new ListItem("09 - September", "09"));
        target.Items.Add(new ListItem("10 - October", "10"));
        target.Items.Add(new ListItem("11 - November", "11"));
        target.Items.Add(new ListItem("12 - December", "12"));
    }

    public static void PopulateExpirationYears(DropDownList target)
    {
        for (int i = DateTime.Now.Year; i < DateTime.Now.Year + 10; i++)
            target.Items.Add(new ListItem(i.ToString(), i.ToString()));
    }
    #endregion
}

